==> giac-1.9.0.7-1-aarch64.pkg.tar.xz: usr/share/giac/doc/nws_sig.js <==
var nws_sig=[
["apps.tar",5160176, [248,159,132,148,216,70,183,145,249,184,137,100,178,29,239,103,175,14,188,64,237,113,62,200,37,12,138,60,208,88,77,44,]],
["apps.tar",5160176, [86,64,84,218,208,31,176,238,15,35,25,99,139,26,173,220,67,173,150,124,31,135,121,30,42,70,171,19,73,152,172,250,]],
["apps.tar",5167632, [190,53,161,241,115,226,91,124,71,90,38,227,224,212,194,211,7,175,218,198,214,45,200,104,43,255,10,227,167,139,190,48,]],
["apps.tar",5190068, [20,17,88,75,207,229,99,124,55,102,74,217,244,15,200,186,248,61,221,104,116,204,66,54,50,226,229,37,23,3,233,58,]],
["apps.tar",5200912, [202,66,17,192,72,158,78,187,133,240,114,253,194,170,207,186,170,122,216,53,175,213,224,139,131,7,212,177,85,229,144,69,]],
["apps.tar",5296144, [214,186,112,8,23,91,128,64,16,0,69,154,148,198,150,42,61,95,29,129,61,174,200,210,45,222,166,63,167,119,112,162,]],
["apps.tar",5296144, [15,75,202,205,161,128,51,0,251,157,28,5,133,134,237,83,240,66,166,11,16,184,189,109,118,133,148,164,179,120,92,165,]],
["apps.tar",5302800, [113,150,227,11,198,224,247,81,169,132,114,227,151,14,83,119,158,233,32,129,78,34,112,155,230,114,195,175,104,134,4,168,]],
["apps.tar",5314576, [141,232,3,203,206,253,228,173,95,143,141,162,0,107,83,175,158,0,133,66,232,118,204,120,182,195,45,42,204,37,12,204,]],  
["apps.tar",5316624, [172,17,215,174,202,255,54,51,183,68,140,182,44,142,153,4,29,17,35,88,85,39,187,169,33,35,189,153,52,167,57,215,]],
["apps.tar",5317136, [0,184,206,113,177,225,142,182,106,0,3,206,152,76,90,165,162,235,49,0,96,48,20,238,68,157,104,157,206,15,117,162,]],
["apps.tar",5320720, [42,13,254,124,47,125,41,133,48,34,93,7,45,52,165,15,239,52,44,59,157,107,81,164,57,226,113,103,209,111,204,56,]],
["apps.tar",5320720, [168,65,53,213,49,182,73,98,33,79,242,234,4,34,188,157,32,185,54,0,197,55,237,62,182,57,0,68,12,82,250,26,]],
["delta.internal.bin",9500, [217,138,145,61,1,227,37,76,41,240,41,246,51,11,120,134,155,155,225,98,47,67,235,20,25,109,228,9,9,216,125,154,]],
["delta.internal.bin",9664, [17,181,104,112,163,76,132,192,131,34,3,120,55,69,26,151,249,111,224,149,86,34,20,137,70,221,140,3,217,235,152,52,]],
["delta.internal.bin",9664, [21,68,28,133,194,152,249,95,237,207,240,197,87,116,24,207,63,129,50,50,200,218,249,170,238,185,243,93,34,163,54,55,]],
["delta.external.bin",1121480, [78,68,180,50,131,105,19,237,22,41,178,255,168,107,94,8,249,237,151,11,14,178,141,28,192,244,199,44,33,83,114,32,]],
["delta.external.bin",1121768, [62,251,116,124,137,86,16,19,47,80,124,139,68,58,2,121,78,60,234,32,173,152,119,17,152,130,116,190,95,44,175,18,]],
["delta.external.bin",1122188, [125,254,217,23,125,177,244,187,137,156,231,198,203,243,163,236,63,51,47,209,157,114,144,223,153,84,163,198,111,197,217,185,]],
["delta.external.bin",1122188, [117,209,180,137,54,216,133,94,67,38,36,1,234,244,79,87,177,181,178,35,185,96,130,67,181,212,15,57,189,98,230,114,]],
["delta.external.bin",1193196, [145,201,71,179,248,57,41,56,252,249,105,230,96,16,22,178,176,52,79,168,224,163,253,30,107,60,163,242,136,221,117,71,]],
["delta.external.bin",1193352, [2,63,97,157,232,64,213,128,161,116,214,198,174,48,174,96,238,86,25,198,213,91,115,43,190,4,90,134,45,194,242,226,]],
["delta.external.bin",1194688, [152,116,58,84,12,149,75,60,203,207,233,193,184,207,115,173,226,32,56,102,139,55,224,213,92,236,232,146,119,118,110,100,]],
["delta.external.bin",1194688, [65,103,70,221,31,31,227,227,133,208,30,213,145,191,193,81,17,104,13,231,35,125,78,106,63,164,1,174,178,191,136,139,]],
["delta.external.bin",1194688, [65,103,70,221,31,31,227,227,133,208,30,213,145,191,193,81,17,104,13,231,35,125,78,106,63,164,1,174,178,191,136,139,]],
["delta.external.bin",1196228, [187,212,241,104,233,92,165,91,157,180,5,136,74,103,27,17,232,56,58,98,92,171,31,19,232,31,68,201,211,226,45,153,]],
["delta.external.bin",1196228, [117,57,146,194,136,159,127,255,16,172,103,224,125,124,18,55,186,181,33,109,9,169,150,96,53,80,40,31,138,255,26,35,]],
["delta.external.bin",1196228, [251,64,17,23,188,24,97,49,232,115,11,178,18,80,229,66,209,57,216,198,109,93,25,159,136,111,248,177,112,61,174,201,]],  
["khi.B.bin",480408, [180,240,247,118,118,90,217,57,162,146,215,100,121,255,138,196,233,65,232,136,11,243,212,139,7,56,26,74,244,184,97,24,]],
["khi.B.bin",480408, [79,100,188,129,202,95,153,138,249,108,7,127,214,162,174,171,185,182,104,72,171,70,227,191,204,218,206,137,103,194,181,112,]],
["khi.B.bin",480132, [47,137,245,147,200,225,93,12,129,108,178,160,191,133,119,208,205,220,50,93,229,154,222,59,85,127,167,45,157,111,138,102,]],
["khi.B.bin",480132, [6,153,186,120,246,101,8,174,71,45,118,200,0,161,175,37,228,203,46,111,201,0,104,240,172,42,110,68,4,94,153,117,]],
["khi.B.bin",480132, [193,125,131,78,169,59,238,41,30,213,4,166,232,4,72,37,134,155,196,204,8,180,216,218,36,154,160,236,53,130,104,23,]],
["delta.external.bin",1196676, [127,237,114,152,227,151,191,234,22,7,178,119,1,46,52,252,83,217,239,62,109,250,171,168,60,198,90,82,231,108,246,230,]],
["khi.B.bin",480156, [35,201,121,36,93,105,117,128,190,97,147,215,157,64,202,78,154,51,107,3,47,87,117,206,187,156,161,124,238,227,63,11,]],
["apps.tar",5321744, [175,137,251,217,154,204,248,190,116,146,5,107,123,233,31,225,205,130,21,116,125,73,191,248,149,131,66,122,49,178,208,206,]],
["delta.external.bin",1197984, [0,115,6,93,135,0,242,4,37,146,61,175,22,211,52,191,223,225,235,201,96,61,113,213,203,54,188,161,208,127,105,234,]],
["khi.B.bin",481980, [182,33,124,152,146,191,46,43,35,59,76,204,114,1,4,41,149,0,36,119,54,138,108,69,134,205,223,35,58,203,229,103,]],
["apps.tar",5323280, [111,0,187,243,207,102,98,187,231,209,193,221,160,174,214,108,102,158,142,135,242,231,67,177,21,53,68,188,153,161,22,177,]],
["delta.external.bin",1197984, [200,43,230,214,147,131,188,110,104,127,160,144,214,10,136,58,214,252,187,94,25,126,203,82,5,65,115,16,86,98,73,130,]],
["khi.B.bin",481980, [215,113,245,79,216,166,164,31,147,24,83,92,18,94,171,165,186,3,120,186,199,205,17,108,159,156,109,176,109,128,205,200,]],
["apps.tar",5324304, [217,140,20,16,178,22,234,149,159,164,222,229,246,116,134,182,217,187,75,251,97,182,58,178,229,92,166,200,21,242,68,239,]],
];

==> giac-1.9.0.998-1-aarch64.pkg.tar.xz: usr/share/giac/doc/nws_sig.js <==
var nws_sig=[
["apps.tar",5160176, [248,159,132,148,216,70,183,145,249,184,137,100,178,29,239,103,175,14,188,64,237,113,62,200,37,12,138,60,208,88,77,44,]],
["apps.tar",5160176, [86,64,84,218,208,31,176,238,15,35,25,99,139,26,173,220,67,173,150,124,31,135,121,30,42,70,171,19,73,152,172,250,]],
["apps.tar",5167632, [190,53,161,241,115,226,91,124,71,90,38,227,224,212,194,211,7,175,218,198,214,45,200,104,43,255,10,227,167,139,190,48,]],
["apps.tar",5190068, [20,17,88,75,207,229,99,124,55,102,74,217,244,15,200,186,248,61,221,104,116,204,66,54,50,226,229,37,23,3,233,58,]],
["apps.tar",5200912, [202,66,17,192,72,158,78,187,133,240,114,253,194,170,207,186,170,122,216,53,175,213,224,139,131,7,212,177,85,229,144,69,]],
["apps.tar",5296144, [214,186,112,8,23,91,128,64,16,0,69,154,148,198,150,42,61,95,29,129,61,174,200,210,45,222,166,63,167,119,112,162,]],
["apps.tar",5296144, [15,75,202,205,161,128,51,0,251,157,28,5,133,134,237,83,240,66,166,11,16,184,189,109,118,133,148,164,179,120,92,165,]],
["apps.tar",5302800, [113,150,227,11,198,224,247,81,169,132,114,227,151,14,83,119,158,233,32,129,78,34,112,155,230,114,195,175,104,134,4,168,]],
["apps.tar",5314576, [141,232,3,203,206,253,228,173,95,143,141,162,0,107,83,175,158,0,133,66,232,118,204,120,182,195,45,42,204,37,12,204,]],  
["apps.tar",5316624, [172,17,215,174,202,255,54,51,183,68,140,182,44,142,153,4,29,17,35,88,85,39,187,169,33,35,189,153,52,167,57,215,]],
["apps.tar",5317136, [0,184,206,113,177,225,142,182,106,0,3,206,152,76,90,165,162,235,49,0,96,48,20,238,68,157,104,157,206,15,117,162,]],
["apps.tar",5320720, [42,13,254,124,47,125,41,133,48,34,93,7,45,52,165,15,239,52,44,59,157,107,81,164,57,226,113,103,209,111,204,56,]],
["apps.tar",5320720, [168,65,53,213,49,182,73,98,33,79,242,234,4,34,188,157,32,185,54,0,197,55,237,62,182,57,0,68,12,82,250,26,]],
["delta.internal.bin",9500, [217,138,145,61,1,227,37,76,41,240,41,246,51,11,120,134,155,155,225,98,47,67,235,20,25,109,228,9,9,216,125,154,]],
["delta.internal.bin",9664, [17,181,104,112,163,76,132,192,131,34,3,120,55,69,26,151,249,111,224,149,86,34,20,137,70,221,140,3,217,235,152,52,]],
["delta.internal.bin",9664, [21,68,28,133,194,152,249,95,237,207,240,197,87,116,24,207,63,129,50,50,200,218,249,170,238,185,243,93,34,163,54,55,]],
["delta.external.bin",1121480, [78,68,180,50,131,105,19,237,22,41,178,255,168,107,94,8,249,237,151,11,14,178,141,28,192,244,199,44,33,83,114,32,]],
["delta.external.bin",1121768, [62,251,116,124,137,86,16,19,47,80,124,139,68,58,2,121,78,60,234,32,173,152,119,17,152,130,116,190,95,44,175,18,]],
["delta.external.bin",1122188, [125,254,217,23,125,177,244,187,137,156,231,198,203,243,163,236,63,51,47,209,157,114,144,223,153,84,163,198,111,197,217,185,]],
["delta.external.bin",1122188, [117,209,180,137,54,216,133,94,67,38,36,1,234,244,79,87,177,181,178,35,185,96,130,67,181,212,15,57,189,98,230,114,]],
["delta.external.bin",1193196, [145,201,71,179,248,57,41,56,252,249,105,230,96,16,22,178,176,52,79,168,224,163,253,30,107,60,163,242,136,221,117,71,]],
["delta.external.bin",1193352, [2,63,97,157,232,64,213,128,161,116,214,198,174,48,174,96,238,86,25,198,213,91,115,43,190,4,90,134,45,194,242,226,]],
["delta.external.bin",1194688, [152,116,58,84,12,149,75,60,203,207,233,193,184,207,115,173,226,32,56,102,139,55,224,213,92,236,232,146,119,118,110,100,]],
["delta.external.bin",1194688, [65,103,70,221,31,31,227,227,133,208,30,213,145,191,193,81,17,104,13,231,35,125,78,106,63,164,1,174,178,191,136,139,]],
["delta.external.bin",1194688, [65,103,70,221,31,31,227,227,133,208,30,213,145,191,193,81,17,104,13,231,35,125,78,106,63,164,1,174,178,191,136,139,]],
["delta.external.bin",1196228, [187,212,241,104,233,92,165,91,157,180,5,136,74,103,27,17,232,56,58,98,92,171,31,19,232,31,68,201,211,226,45,153,]],
["delta.external.bin",1196228, [117,57,146,194,136,159,127,255,16,172,103,224,125,124,18,55,186,181,33,109,9,169,150,96,53,80,40,31,138,255,26,35,]],
["delta.external.bin",1196228, [251,64,17,23,188,24,97,49,232,115,11,178,18,80,229,66,209,57,216,198,109,93,25,159,136,111,248,177,112,61,174,201,]],  
["khi.B.bin",480408, [180,240,247,118,118,90,217,57,162,146,215,100,121,255,138,196,233,65,232,136,11,243,212,139,7,56,26,74,244,184,97,24,]],
["khi.B.bin",480408, [79,100,188,129,202,95,153,138,249,108,7,127,214,162,174,171,185,182,104,72,171,70,227,191,204,218,206,137,103,194,181,112,]],
["khi.B.bin",480132, [47,137,245,147,200,225,93,12,129,108,178,160,191,133,119,208,205,220,50,93,229,154,222,59,85,127,167,45,157,111,138,102,]],
["khi.B.bin",480132, [6,153,186,120,246,101,8,174,71,45,118,200,0,161,175,37,228,203,46,111,201,0,104,240,172,42,110,68,4,94,153,117,]],
["khi.B.bin",480132, [193,125,131,78,169,59,238,41,30,213,4,166,232,4,72,37,134,155,196,204,8,180,216,218,36,154,160,236,53,130,104,23,]],
["delta.external.bin",1196676, [127,237,114,152,227,151,191,234,22,7,178,119,1,46,52,252,83,217,239,62,109,250,171,168,60,198,90,82,231,108,246,230,]],
["khi.B.bin",480156, [35,201,121,36,93,105,117,128,190,97,147,215,157,64,202,78,154,51,107,3,47,87,117,206,187,156,161,124,238,227,63,11,]],
["apps.tar",5321744, [175,137,251,217,154,204,248,190,116,146,5,107,123,233,31,225,205,130,21,116,125,73,191,248,149,131,66,122,49,178,208,206,]],
["delta.external.bin",1197984, [0,115,6,93,135,0,242,4,37,146,61,175,22,211,52,191,223,225,235,201,96,61,113,213,203,54,188,161,208,127,105,234,]],
["khi.B.bin",481980, [182,33,124,152,146,191,46,43,35,59,76,204,114,1,4,41,149,0,36,119,54,138,108,69,134,205,223,35,58,203,229,103,]],
["apps.tar",5323280, [111,0,187,243,207,102,98,187,231,209,193,221,160,174,214,108,102,158,142,135,242,231,67,177,21,53,68,188,153,161,22,177,]],
["delta.external.bin",1197984, [200,43,230,214,147,131,188,110,104,127,160,144,214,10,136,58,214,252,187,94,25,126,203,82,5,65,115,16,86,98,73,130,]],
["khi.B.bin",481980, [215,113,245,79,216,166,164,31,147,24,83,92,18,94,171,165,186,3,120,186,199,205,17,108,159,156,109,176,109,128,205,200,]],
["apps.tar",5324304, [217,140,20,16,178,22,234,149,159,164,222,229,246,116,134,182,217,187,75,251,97,182,58,178,229,92,166,200,21,242,68,239,]],
["delta.external.bin",1198008, [254,130,115,90,61,55,143,168,192,4,100,249,167,237,191,217,97,22,110,168,207,118,64,125,254,159,125,175,187,132,111,244,]],
["khi.B.bin",482004, [194,159,72,172,50,51,187,222,216,49,212,195,5,238,219,151,163,198,155,90,73,39,137,15,236,87,41,189,220,131,76,174,]],
["apps.tar",5337616, [33,152,31,31,81,80,245,198,219,62,12,17,90,212,116,105,201,164,248,49,163,171,107,150,15,139,1,141,136,207,133,208,]],
["delta.external.bin",1198008, [141,47,29,153,228,165,27,245,201,30,81,168,140,199,11,68,47,251,102,251,51,174,169,50,231,44,236,144,82,158,4,119,]],
["khi.B.bin",482004, [221,195,204,185,237,192,105,92,154,45,198,80,216,64,9,229,76,32,225,191,215,28,101,31,156,124,22,231,171,149,76,43,]],
["apps.tar",5402128, [253,212,31,15,168,52,189,194,213,145,168,29,197,166,58,70,45,74,160,62,29,46,134,92,215,143,96,101,99,137,151,109,]],
["delta.external.bin",1194284, [198,2,224,27,58,115,208,164,65,121,19,69,127,137,7,199,92,157,120,103,122,33,89,226,228,122,96,252,85,133,217,253,]],
["khi.B.bin",481000, [24,206,76,146,68,46,44,121,58,188,24,112,27,180,18,1,241,246,194,20,241,95,246,111,33,129,230,166,121,224,254,214,]],
["apps.tar",5461520, [176,130,3,240,17,68,21,208,194,208,125,85,247,173,146,12,21,214,180,183,225,192,251,182,100,168,81,4,173,157,102,34,]],
["delta.external.bin",1194284, [115,8,70,21,75,216,151,211,196,138,239,181,102,79,161,236,41,202,215,189,227,10,59,162,134,217,226,10,88,50,189,79,]],
["khi.B.bin",481000, [246,62,228,193,203,68,8,80,39,255,212,144,189,94,226,125,146,153,93,139,97,219,4,167,67,69,66,237,90,189,71,98,]],
["apps.tar",5470736, [209,86,214,150,226,105,106,93,185,18,6,212,156,44,174,56,120,250,26,94,104,157,134,83,78,163,182,27,47,62,6,72,]],
["delta.external.bin",1202316, [2,51,127,106,77,9,110,238,185,74,239,165,11,86,126,12,108,96,137,198,8,4,223,59,99,42,152,58,96,237,50,145,]],
["khi.B.bin",485940, [207,212,6,243,42,22,166,11,171,185,43,60,107,220,94,114,189,37,224,254,59,82,79,124,45,32,170,182,92,181,216,73,]],
["apps.tar",5483536, [15,16,179,120,214,125,79,101,122,254,130,232,143,156,253,238,254,232,132,119,192,67,30,93,108,8,220,191,80,127,71,151,]],
];
